@@ -32,7 +32,7 @@
  * may use your version of this file under either the MPL or the
  * GPL.
  *
- * $Id: nss.h,v 1.18.2.7 2002/04/24 14:51:26 relyea%netscape.com Exp $
+ * $Id: nss.h,v 1.22.4.1 2002/10/08 01:10:25 wtc%netscape.com Exp $
  */
 
 #ifndef __nss_h_
@@ -49,10 +49,10 @@ SEC_BEGIN_PROTOS
  * The format of the version string should be
  *     "<major version>.<minor version>[.<patch level>] [<Beta>]"
  */
-#define NSS_VERSION  "3.4.1 RTM"
+#define NSS_VERSION  "3.6"
 #define NSS_VMAJOR   3
-#define NSS_VMINOR   4
-#define NSS_VPATCH   1
+#define NSS_VMINOR   6
+#define NSS_VPATCH   0
 #define NSS_BETA     PR_FALSE
 
 
@@ -110,6 +110,7 @@ extern SECStatus NSS_InitReadWrite(const char *configdir);
  * 			databases cannot be opened.
  *      NSS_INIT_NOROOTINIT - Don't try to look for the root certs module
  *			automatically.
+ *      NSS_INIT_OPTIMIZESPACE - Use smaller tables and caches.
  *
  * Also NOTE: This is not the recommended method for initializing NSS. 
  * The prefered method is NSS_init().
@@ -119,6 +120,7 @@ extern SECStatus NSS_InitReadWrite(const char *configdir);
 #define NSS_INIT_NOMODDB	0x4
 #define NSS_INIT_FORCEOPEN	0x8
 #define NSS_INIT_NOROOTINIT     0x10
+#define NSS_INIT_OPTIMIZESPACE  0x20
 
 extern SECStatus NSS_Initialize(const char *configdir, 
 	const char *certPrefix, const char *keyPrefix, 
@@ -132,7 +134,7 @@ SECStatus NSS_NoDB_Init(const char *configdir);
 /* 
  * Close the Cert, Key databases.
  */
-extern void NSS_Shutdown(void);
+extern SECStatus NSS_Shutdown(void);
 
 /*
  * set the PKCS #11 strings for the internal token.
